@@ -1,21 +1,15 @@
 import asyncio
-from typing import Any, ClassVar
-from typing_extensions import override
+from collections.abc import Callable
+from typing import Any, ClassVar, Generic, TypeVar
 
 from nonebot.adapters import Adapter, Bot, Event, Message, MessageSegment
-from nonebot.internal.matcher import current_event
-from nonebot.log import logger
 from nonebot_plugin_alconna.uniseg import Receipt, Target, UniMessage
-from nonebot_plugin_session import Session
+from nonebot_plugin_session import Session, SessionIdType
 from nonebot_plugin_waiter import prompt as waiter_prompt
+from typing_extensions import override
 
-from ..constant import (
-    INTERFACE_METHOD_DESCRIPTION,
-    T_Context,
-    T_ForwardMsg,
-    T_Message,
-    T_OptConstVar,
-)
+from ..constant import INTERFACE_METHOD_DESCRIPTION
+from ..typings import T_ConstVar, T_Context, T_Message
 from .group import Group
 from .help_doc import FuncDescription, descript, message_alia
 from .interface import Interface
@@ -23,25 +17,28 @@ from .user import User
 from .user_const_var import default_context, load_const, set_const
 from .utils import (
     Buffer,
+    as_msg,
     as_unimsg,
     debug_log,
     export,
+    export_message,
     export_superuser,
     is_export_method,
     is_message_t,
     is_super_user,
-    send_forward_message,
     send_message,
+    strict,
 )
 
-logger = logger.opt(colors=True)
 api_registry: dict[type[Adapter], type["API"]] = {}
 message_alia(Message, MessageSegment)
+_A = TypeVar("_A", bound=type["API"])
+_B = TypeVar("_B", bound=Bot)
+_E = TypeVar("_E", bound=Event)
 
 
-def register_api(adapter: type[Adapter]):
-
-    def decorator(api: type["API"]) -> type["API"]:
+def register_api(adapter: type[Adapter]) -> Callable[[_A], _A]:
+    def decorator(api: _A) -> _A:
         api_registry[adapter] = api
         adapter_name = adapter.get_name()
         for desc in api.__method_description__.values():
@@ -51,25 +48,72 @@ def register_api(adapter: type[Adapter]):
     return decorator
 
 
-class API(Interface):
+class API(Generic[_B, _E], Interface):
     __inst_name__: ClassVar[str] = "api"
 
-    bot: Bot
-    qid: str
-    gid: str | None
-    session: Session
-    event: Event
+    def __init__(
+        self,
+        bot: _B,
+        event: _E,
+        session: Session,
+        context: T_Context,
+    ) -> None:
+        if not self._validate(bot, event):
+            raise RuntimeError("Bot/Event type mismatch")
 
-    def __init__(self, bot: Bot, session: Session) -> None:
-        super().__init__()
-        self.bot = bot
-        self.qid = session.id1 or ""
-        self.gid = session.id2
-        self.session = session
-        self.event = current_event.get()
+        super().__init__(context)
+        self.__bot = bot
+        self.__event = event
+        self.__session = session
 
-    async def _native_send(self, msg: str | Message | MessageSegment) -> Any:
-        return await self.bot.send(self.event, msg)
+    @property
+    def bot(self) -> _B:
+        return self.__bot
+
+    @property
+    def event(self) -> _E:
+        return self.__event
+
+    @property
+    def session(self) -> Session:
+        return self.__session
+
+    @property
+    def qid(self) -> str:
+        return self.session.id1 or ""
+
+    @property
+    def gid(self) -> str | None:
+        return self.session.id2
+
+    @property
+    def session_id(self) -> str:
+        return self.session.get_id(SessionIdType.USER).replace(" ", "_")
+
+    @property
+    def mid(self) -> str | int:
+        raise NotImplementedError
+
+    @classmethod
+    def _validate(cls, bot: _B, event: _E) -> bool:  # noqa: ARG003
+        return True
+
+    @descript(
+        description="调用 bot.send 向当前会话发送平台消息",
+        parameters=dict(
+            msg="要发送的消息",
+            kwds="任意额外参数",
+        ),
+        result="bot.send 的返回值",
+    )
+    @debug_log
+    @strict
+    async def native_send(
+        self,
+        msg: Any,
+        **kwds: Any,
+    ) -> Any:
+        return await self.bot.send(self.event, await as_msg(msg), **kwds)
 
     @descript(
         description="向QQ号为qid的用户发送私聊消息",
@@ -79,6 +123,7 @@ class API(Interface):
         ),
     )
     @debug_log
+    @strict
     async def send_prv(self, qid: int | str, msg: T_Message) -> Receipt:
         return await send_message(
             session=self.session,
@@ -94,6 +139,7 @@ class API(Interface):
         ),
     )
     @debug_log
+    @strict
     async def send_grp(self, gid: int | str, msg: T_Message) -> Receipt:
         return await send_message(
             session=self.session,
@@ -101,50 +147,6 @@ class API(Interface):
             message=msg,
         )
 
-    @descript(
-        description="向QQ号为qid的用户发送合并转发消息",
-        parameters=dict(
-            qid="需要发送消息的QQ号",
-            msgs="发送的消息列表",
-        ),
-        result="Receipt",
-    )
-    @debug_log
-    async def send_prv_fwd(self, qid: int | str, msgs: T_ForwardMsg) -> Receipt:
-        return await send_forward_message(
-            session=self.session,
-            target=Target.user(str(qid)),
-            msgs=msgs,
-        )
-
-    @descript(
-        description="向群号为gid的群聊发送合并转发消息",
-        parameters=dict(
-            gid="需要发送消息的群号",
-            msgs="发送的消息列表",
-        ),
-    )
-    @debug_log
-    async def send_grp_fwd(self, gid: int | str, msgs: T_ForwardMsg) -> Receipt:
-        return await send_forward_message(
-            session=self.session,
-            target=Target.group(str(gid)),
-            msgs=msgs,
-        )
-
-    @export
-    @descript(
-        description="向当前会话发送合并转发消息",
-        parameters=dict(msgs="发送的消息列表"),
-    )
-    @debug_log
-    async def send_fwd(self, msgs: T_ForwardMsg) -> Receipt:
-        return await send_forward_message(
-            session=self.session,
-            target=None,
-            msgs=msgs,
-        )
-
     @export
     @descript(
         description="向当前会话发送消息",
@@ -154,11 +156,8 @@ class API(Interface):
         ),
     )
     @debug_log
-    async def feedback(self, msg: Any, fwd: bool = False) -> Receipt:
-        if isinstance(msg, list):
-            if fwd and all(is_message_t(i) for i in msg):
-                return await self.send_fwd(msg)
-
+    @strict
+    async def feedback(self, msg: Any) -> Receipt:
         if not is_message_t(msg):
             msg = str(msg)
 
@@ -171,19 +170,21 @@ class API(Interface):
     @export
     @descript(
         description="获取用户对象",
-        parameters=dict(qid="用户QQ号"),
+        parameters=dict(uid="用户ID"),
         result="User对象",
     )
-    def user(self, qid: int | str) -> "User":
-        return User(self, str(qid))
+    @strict
+    def user(self, uid: int | str) -> "User[API]":
+        return User(self, str(uid))
 
     @export
     @descript(
         description="获取群聊对象",
-        parameters=dict(gid="群号"),
+        parameters=dict(gid="群组ID"),
         result="Group对象",
     )
-    def group(self, gid: int | str) -> "Group":
+    @strict
+    def group(self, gid: int | str) -> "Group[API]":
         return Group(self, str(gid))
 
     @descript(
@@ -192,6 +193,7 @@ class API(Interface):
         result="当前会话为群聊返回True，否则返回False",
     )
     @debug_log
+    @strict
     def is_group(self) -> bool:
         return not UniMessage.get_target().private
 
@@ -203,54 +205,50 @@ class API(Interface):
         ),
     )
     @debug_log
-    def set_const(self, name: str, value: T_OptConstVar = None) -> None:
+    @strict
+    def set_const(self, name: str, value: T_ConstVar = None) -> None:
         if value is None:
-            set_const(self.qid, name)
+            set_const(self.session_id, name)
             return
 
-        try:
-            set_const(self.qid, name, value)
-        except TypeError as e:
-            raise TypeError("设置常量的值必须可被json序列化") from e
+        set_const(self.session_id, name, value)
 
     @export
     @debug_log
-    def print(self, *args: Any, sep: str = " ", end: str = "\n", **_):
-        Buffer.get(self.qid).write(str(sep).join(map(str, args)) + str(end))
+    def print(self, *args: Any, sep: str = " ", end: str = "\n", **_: Any) -> None:
+        buffer = Buffer.get(self.session.get_id(1).replace(" ", "_"))
+        buffer.write(str(sep).join(map(str, args)) + str(end))
 
     @export
     @debug_log
+    @strict
     async def input(
         self,
-        prompt: T_Message = "",
+        prompt: T_Message | None = None,
         timeout: float = 30,
     ) -> UniMessage:
-        prompt = await (await as_unimsg(prompt)).export() if prompt else ""
+        prompt = (
+            await (await as_unimsg(prompt)).export(self.bot)
+            if prompt is not None
+            else ""
+        )
         if result := await waiter_prompt(prompt, timeout=timeout):
             return await UniMessage.generate(message=result)
         raise TimeoutError("input 超时")
 
     @export
     @descript(
-        description="向当前会话发送API说明",
-        parameters=dict(method="需要获取帮助的函数，留空则为完整文档"),
+        description="向当前会话发送 API 说明",
+        parameters=dict(method="需要获取帮助的函数"),
     )
     @debug_log
-    async def help(self, method: Any = ...) -> Receipt:
-        if method is not ...:
-            desc: FuncDescription = getattr(method, INTERFACE_METHOD_DESCRIPTION)
-            text = desc.format(method)
-            if not is_export_method(method):
-                text = f"{self.__inst_name__}.{text}"
-            return await self.feedback(text)
-
-        content, description = self._get_all_description()
-        msgs: list[T_Message] = [
-            "   ===== API说明 =====   ",
-            " - API说明文档 - 目录 - \n" + "\n".join(content),
-            *description,
-        ]
-        return await self.feedback(msgs, fwd=True)
+    @strict
+    async def help(self, method: Callable) -> None:
+        desc: FuncDescription = getattr(method, INTERFACE_METHOD_DESCRIPTION)
+        text = desc.format(method)
+        if not is_export_method(method):
+            text = f"{self.__inst_name__}.{text}"
+        await self.feedback(UniMessage.text(text))
 
     @export
     @descript(
@@ -258,6 +256,7 @@ class API(Interface):
         parameters=dict(seconds="等待的时间，单位秒"),
     )
     @debug_log
+    @strict
     async def sleep(self, seconds: float) -> None:
         await asyncio.sleep(seconds)
 
@@ -273,18 +272,22 @@ class API(Interface):
         context = Context.get_context(self.session).ctx
         context.clear()
         context.update(default_context)
-        self.export_to(context)
+        self.export()
 
     @override
-    def export_to(self, context: T_Context) -> None:
-        super().export_to(context)
+    def export(self) -> None:
+        super().export()
 
-        context.update(load_const(self.qid))
-        context["qid"] = self.qid
-        context["gid"] = self.gid
+        for k, v in load_const(self.session_id).items():
+            self._export(k, v)
+        self._export("qid", self.qid)
+        self._export("gid", self.gid)
+        for k, v in export_message(self.bot.adapter).items():
+            self._export(k, v)
 
         if is_super_user(self.bot, self.qid):
-            export_superuser(context)
+            for k, v in export_superuser().items():
+                self._export(k, v)
 
     def __repr__(self) -> str:
-        return f"{self.__class__.__name__}(user_id={self.qid})"
+        return f"<{self.__class__.__name__} user_id={self.qid}>"
