@@ -1,3 +1,5 @@
+# ruff: noqa: S101
+
 import inspect
 from collections.abc import Callable
 from dataclasses import dataclass
@@ -11,10 +13,8 @@ from ..constant import (
     DESCRIPTION_RECEIPT_TYPE,
     DESCRIPTION_RESULT_TYPE,
     INTERFACE_METHOD_DESCRIPTION,
-    T_ForwardMsg,
-    T_Message,
-    T_OptConstVar,
 )
+from ..typings import T_ConstVar, T_ForwardMsg, T_Message
 from .utils import Result
 
 EMPTY = inspect.Signature.empty
@@ -24,22 +24,22 @@ R = TypeVar("R")
 type_alias: dict[Any, str] = {
     Receipt: "Receipt",
     Result: "Result",
+    T_ConstVar: "T_ConstVar",
     T_Message: "T_Message",
     T_ForwardMsg: "T_ForwardMsg",
-    T_OptConstVar: "Optional[T_ConstVar]",
     EMPTY: "Unkown",  # not supposed to appear in docs
 }
 
 
-def message_alia(M: type[Message], MS: type[MessageSegment]) -> None:
-    type_alias[M] = "Message"
-    type_alias[MS] = "MessageSegment"
+def message_alia(m: type[Message], ms: type[MessageSegment]) -> None:
+    type_alias[m] = "Message"
+    type_alias[ms] = "MessageSegment"
 
 
-def _type_string(t: type | str) -> str:
+def format_annotation(t: type | str) -> str:
     if isinstance(t, str):
         return t
-    elif t in type_alias:
+    if t in type_alias:
         return type_alias[t]
     return inspect.formatannotation(t)
 
@@ -47,11 +47,11 @@ def _type_string(t: type | str) -> str:
 def func_declaration(func: Callable[..., Any], ignore: set[str]) -> str:
     sig = inspect.signature(func)
     params = [
-        f"{name}: {_type_string(param.annotation)}"
+        f"{name}: {format_annotation(param.annotation)}"
         for name, param in sig.parameters.items()
         if name not in ignore
     ]
-    result = _type_string(sig.return_annotation)
+    result = format_annotation(sig.return_annotation)
 
     return f"{func.__name__}({', '.join(params)}) -> {result}"
 
@@ -63,7 +63,7 @@ class FuncDescription:
     result: str | None
     ignore: set[str]
 
-    def format(self, func: Callable[..., Any]):
+    def format(self, func: Callable[..., Any]) -> str:
         return DESCRIPTION_FORMAT.format(
             decl=func_declaration(func, self.ignore),
             desc=self.description,
@@ -98,11 +98,6 @@ def descript(
                 assert name in parameters, f"{text} 未添加描述"
 
         ret = sig.return_annotation
-        # if origin := getattr(ret, "__origin__", None):
-        #     args: tuple[type, ...] = getattr(ret, "__args__")
-        #     if origin is Awaitable:
-        #         ret = args[0]
-
         text = f"方法 {call.__name__!r} 的返回值"
         assert ret is not EMPTY, f"{text} 未添加类型注释"
 
