@@ -3,7 +3,8 @@ from typing import Any, ClassVar, NamedTuple, cast
 
 from typing_extensions import Self
 
-from ..constant import INTERFACE_METHOD_DESCRIPTION, T_Context
+from ..constant import INTERFACE_METHOD_DESCRIPTION
+from ..typings import T_Context
 from .help_doc import FuncDescription
 from .utils import is_export_method
 
@@ -29,7 +30,7 @@ class Interface:
 
     def __init_subclass__(cls) -> None:
         if cls.__inst_name__ == Interface.__inst_name__:
-            cls.__inst_name__ = cls.__name__.lower()
+            cls.__inst_name__ = cls.__name__.lower()  # pragma: no cover
         cls.__export_method__ = [
             name for name, value in cls.__dict__.items() if is_export_method(value)
         ]
@@ -40,7 +41,7 @@ class Interface:
         }
 
     def _export(self, key: str, val: Any) -> None:
-        if self.__context is None:
+        if self.__context is None:  # pragma: no cover
             raise TypeError(
                 f"Interface class {type(self).__name__!r} not allowed to export"
             )
@@ -88,11 +89,15 @@ class Interface:
 
     @classmethod
     def get_all_description(cls) -> tuple[list[str], list[str]]:
-        methods: list[_Desc] = []
+        method_dict: dict[str, _Desc] = {}
         for c in cls.mro():
             if issubclass(c, Interface):
-                methods.extend(c._get_method_description())  # noqa: SLF001
-        methods.sort(key=lambda x: (1 - x.is_export, x.inst_name, x.func_name))
+                for desc in c._get_method_description():  # noqa: SLF001
+                    method_dict.setdefault(desc.func_name, desc)
+        methods = sorted(
+            method_dict.values(),
+            key=lambda x: (1 - x.is_export, x.inst_name, x.func_name),
+        )
 
         content: list[str] = []
         result: list[str] = []
